==> dna-web-jcr-rest-0.5-sources.jar: org/jboss/dna/web/jcr/rest/model/WorkspaceEntry.java <==
/*
 * JBoss DNA (http://www.jboss.org/dna)
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * See the AUTHORS.txt file in the distribution for a full listing of 
 * individual contributors. 
 *
 * JBoss DNA is free software. Unless otherwise indicated, all code in JBoss DNA
 * is licensed to you under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * JBoss DNA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.dna.web.jcr.rest.model;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement( name = "workspace" )
public class WorkspaceEntry {

    private String name;
    private WorkspaceResources resources;

    public WorkspaceEntry() {

    }

    public WorkspaceEntry( String contextName,
                           String repositoryName,
                           String workspaceName ) {
        this.name = workspaceName;

        resources = new WorkspaceResources(contextName, repositoryName, workspaceName);
    }

    @XmlElement
    public String getName() {
        return name;
    }

    @XmlElement
    public WorkspaceResources getResources() {
        return resources;
    }
}

==> dna-web-jcr-rest-0.7-sources.jar: org/jboss/dna/web/jcr/rest/model/WorkspaceEntry.java <==
/*
 * JBoss DNA (http://www.jboss.org/dna)
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * See the AUTHORS.txt file in the distribution for a full listing of 
 * individual contributors. 
 *
 * JBoss DNA is free software. Unless otherwise indicated, all code in JBoss DNA
 * is licensed to you under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * JBoss DNA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.dna.web.jcr.rest.model;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement( name = "workspace" )
public class WorkspaceEntry {

    private String name;
    private WorkspaceResources resources;

    public WorkspaceEntry() {

    }

    public WorkspaceEntry( String contextName,
                           String repositoryName,
                           String workspaceName ) {
        this.name = workspaceName;

        resources = new WorkspaceResources(contextName, repositoryName, workspaceName);
    }

    @XmlElement
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @XmlElement
    public WorkspaceResources getResources() {
        return resources;
    }

    public void setResources(WorkspaceResources resources) {
        this.resources = resources;
    }
}
